==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ar/issues.php <==
<?php
regGS("Issue List", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "      ( الاسم <br> (إضغط لترى الإصدارات");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "نشر<br> (السنة، الشهر، اليوم");
regGS("Delete issue $1", "الغاء  الإصدار$1");
regGS("Publish articles", "نشر المقالات");
regGS("Issue automatic publishing schedule", "جدول النشر الآلي للعدد");
regGS("Change issue status", "بدّل وضع الإصدار");
regGS("You do not have the right to change issues.", "لا يحق لك تغيير الإصدارات");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "هل أنت متأكد من أنك تريد تغيير وضع الإصدار  $1 من $2 إلى $3؟");
regGS("Changing issue status", "تغيير وضع الإصدار");
regGS("Status of the issue $1 has been changed from $2 to $3", "تمّ تغيير وضع الإصدار $1 من$2 إلى $3");
regGS("Status of the issue $1 could not be changed.", "لا يمكن تغيير الإصدار $1");
regGS("Add new translation", "إضافة ترجمة جديدة");
regGS("You do not have the right to add issues.", "لا يحق لك إضافة إصدارات");
regGS("The issue $1 has been successfuly added.", "تمت إضافة الإصدار $1");
regGS("The issue could not be added.", "لا يمكن إضافة الإصدار");
regGS("Please check if another issue with the same number/language does not already exist.", "    الرجاء التأكد من عدم وجود إصدار يحمل الرقم نفسه/ اللغة نفسها");
regGS("Change issue details", "بدّل تفاصيل الإصدار");
regGS("You do not have the right to change issue details.", "لا يحق لك تغيير تفاصيل الإصدار");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "تاريخ النشر <br>");
regGS("Front Page Template", "قالب الصفحة الأمامية");
regGS("Updating issue", "تحديث الإصدار");
regGS("Changing issue's details", "تغيير تفاصيل الإصدار");
regGS("The issue $1 has been successfuly changed.", "تم تغيير الإصدار $1");
regGS("The issue could not be changed.", "لا يمكن تغيير الإصدار");
regGS("Issue $1 updated in publication $2", " تحديث الإصدار $1 في المنشور $2");
regGS("You do not have the right to delete issues.", "لا يحق لك إلغاء الإصدارات");
regGS("Are you sure you want to delete the issue $1?", "هل أنت متأكد من أنك تريد إلغاء الإصدار $1 ؟  ");
regGS("Deleting issue", "إلغاء الإصدار");
regGS("Use the structure of the previous issue", "إستخدم هيكلية الإصدار السابق");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "إنسخ الهيكلية الكاملة باللغات كلها من الإصدار السابق باستثناء المحتوى");
regGS("You may modify it later if you wish.", "يمكنك تغييره لاحقا إذا أردت");
regGS("Create a new structure", "حدّد إخلق هيكلية جديدة");
regGS("Create a complete new structure.", "حدّد هيكلية جديدة متكاملة");
regGS("You must define an issue type for each language and then sections for them.", "عليك أن تحدد نوع الإصدار لكلّ لغة ومن ثم الأبواب الخاصة بها");
regGS("Copy previous issue", "إنسخ الإصدار السابق");
regGS("No previous issue.", "لا يوجد إصدار سابق");
regGS("Copy structure from issue nr $1", "إنسخ الهيكلية من الإصدار رقم $1");
regGS("Copying previous issue", "نسخ الإصدار السابق");
regGS("Select the issue", "إختر الإصدار");
regGS("New issue $1 from $2 in publication $3", "إصدار $1 جديد من $2 في المنشور $3");
regGS("Adding new issue", "إضافة إصدار جديد");
regGS("Changing issue template", "تغيير نموذج الإصدار");
regGS("You do not have the right to change issue templates.", "لا يحق لك تغيير نماذج الإصدار");
regGS("Changing issue template for front page", "تغيير نموذج الإصدار للصفحة الرئيسية");
regGS("Changing issue template for single article", "تغيير نموذج الإصدار للمقال المنفرد");
regGS("The template has been successfully changed.", "تم تغيير النموذج بنجاح");
regGS("Issue template for publication $1 changed to $2", "تغيير  نموذج الإصدار من المنشور$1  إلى $2");
regGS("Issue template for single articles from $1 changed to $2", " تغيير نموذج الإصدار للمقالات المنفردة من $1  إلى $2");
regGS("The template could not be changed.", "لا يمكن تغيير النموذج");
regGS("Delete entry", "إلغاء المدخل");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/ar/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "      ( الاسم <br> (إضغط لترى الإصدارات");
regGS("Delete issue $1", "الغاء  الإصدار$1");
regGS("Publish articles", "نشر المقالات");
regGS("You do not have the right to change issues.", "لا يحق لك تغيير الإصدارات");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "هل أنت متأكد من أنك تريد تغيير وضع الإصدار  $1 من $2 إلى $3؟");
regGS("Add new translation", "إضافة ترجمة جديدة");
regGS("You do not have the right to add issues.", "لا يحق لك إضافة إصدارات");
regGS("The issue $1 has been successfuly added.", "تمت إضافة الإصدار $1");
regGS("The issue could not be added.", "لا يمكن إضافة الإصدار");
regGS("Change issue details", "بدّل تفاصيل الإصدار");
regGS("You do not have the right to change issue details.", "لا يحق لك تغيير تفاصيل الإصدار");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "تاريخ النشر <br>");
regGS("Front Page Template", "قالب الصفحة الأمامية");
regGS("Issue $1 updated in publication $2", " تحديث الإصدار $1 في المنشور $2");
regGS("You do not have the right to delete issues.", "لا يحق لك إلغاء الإصدارات");
regGS("Are you sure you want to delete the issue $1?", "هل أنت متأكد من أنك تريد إلغاء الإصدار $1 ؟  ");
regGS("Use the structure of the previous issue", "إستخدم هيكلية الإصدار السابق");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "إنسخ الهيكلية الكاملة باللغات كلها من الإصدار السابق باستثناء المحتوى");
regGS("You may modify it later if you wish.", "يمكنك تغييره لاحقا إذا أردت");
regGS("Create a new structure", "حدّد إخلق هيكلية جديدة");
regGS("Create a complete new structure.", "حدّد هيكلية جديدة متكاملة");
regGS("You must define an issue type for each language and then sections for them.", "عليك أن تحدد نوع الإصدار لكلّ لغة ومن ثم الأبواب الخاصة بها");
regGS("Copy previous issue", "إنسخ الإصدار السابق");
regGS("No previous issue.", "لا يوجد إصدار سابق");
regGS("Copy structure from issue number $1", "إنسخ الهيكلية من الإصدار رقم $1");
regGS("New issue $1 from $2 in publication $3", "إصدار $1 جديد من $2 في المنشور $3");
regGS("Delete entry", "إلغاء المدخل");
regGS("Issue Publishing Schedule", "جدول نشر العدد");
regGS("Invalid Input: $1", "إدخال غير مقبول: $1");
regGS("Issue Number", "رقم العدد");
regGS("Go To Sections", "إذهب إلى الأقسام");
regGS("Issue automatic publishing schedule", "جدول النشر الآلي للعدد");
regGS("Changing issue status", "تغيير وضع الإصدار");
regGS("Status of the issue $1 has been changed from $2 to $3", "تمّ تغيير وضع الإصدار $1 من$2 إلى $3");
regGS("Status of the issue $1 could not be changed.", "لا يمكن تغيير الإصدار $1");
regGS("Updating issue", "تحديث الإصدار");
regGS("Changing issue's details", "تغيير تفاصيل الإصدار");
regGS("The issue $1 has been successfuly changed.", "تم تغيير الإصدار $1");
regGS("The issue could not be changed.", "لا يمكن تغيير الإصدار");
regGS("Changing issue template", "تغيير نموذج الإصدار");
regGS("You do not have the right to change issue templates.", "لا يحق لك تغيير نماذج الإصدار");
regGS("Changing issue template for front page", "تغيير نموذج الإصدار للصفحة الرئيسية");
regGS("Changing issue template for single article", "تغيير نموذج الإصدار للمقال المنفرد");
regGS("The template has been successfully changed.", "تم تغيير النموذج بنجاح");
regGS("Issue template for publication $1 changed to $2", "تغيير  نموذج الإصدار من المنشور$1  إلى $2");
regGS("Issue template for single articles from $1 changed to $2", " تغيير نموذج الإصدار للمقالات المنفردة من $1  إلى $2");
regGS("The template could not be changed.", "لا يمكن تغيير النموذج");
regGS("There was an error reading the language parameter.", "هنالك خطاء في قراءة متغيرات اللغة");
regGS("There was an error reading the publication parameter.", "هنالك خطاء في قراءة متغيرات المنشور");
regGS("There was an error reading the issue parameter.", "هنالك خطاء في قراءة متغيرات العدد");
regGS("There was an error scheduling the $1 action on $2", "حدث خطاء في جدولة $1 في $2");
regGS("The action scheduled on $1 could not be deleted.", "العملية المجدولة في $1 لا يمكن إلغاؤها");
?>
